For each package, list the links to the
dedicated GitHub Pages website(s).
If there are vignettes, add those as well.
If the GitHub Pages website for a package does not exist,
NULL will be returned for that package.
Arguments
- meta
A metadata data.table produced by package_metadata. Alternatively, can be a character vector of packages to gather metadata for, passed to package_metadata.
- add_vignettes
Search for any vignettes on the GitHub Pages websites, and add them to a new column named "ghpages_vignettes".
- verbose
Print messages.
Value
data.table of metadata.